Crate lambda_runtime_api_client

Crate lambda_runtime_api_client 

This crate includes a base HTTP client to interact with the AWS Lambda Runtime API.

Modules

body
HTTP body utilities. Extracted from Axum under MIT license. https://github.com/tokio-rs/axum/blob/main/axum/LICENSE
tracingtracing
This module provides primitives to work with tracing and tracing-subscriber in Lambda functions.

Structs

Client
API client to interact with the AWS Lambda Runtime API.
ClientBuilder
Builder implementation to construct any Runtime API clients.
Error
Errors that can happen when using axum.
PooledClient
API client to interact with the AWS Lambda Runtime API, with support for rebuilding its connection pool after a SnapStart VM restore.
PooledClientBuilder
Builder to construct a PooledClient.

Traits

RuntimeApiClient
The single method the runtime needs from any client: send a request to the Lambda Runtime API (RAPID). Implemented by both Client and PooledClient.

Functions

build_request
Create a request builder. This builder uses aws-lambda-rust/CRATE_VERSION as the default User-Agent. Configure environment variable LAMBDA_RUNTIME_USER_AGENT at compile time to modify User-Agent value.

Type Aliases

BoxError
Alias for a type-erased error type.